<?php

namespace Wilsonwaldo\Sisep\Providers;

use Illuminate\Support\ServiceProvider;

class SisepServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'sisep');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'sisep');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('wilsonwaldo.sisep', function ($app) {
            return $this->app->make('Wilsonwaldo\Sisep\Sisep');
        });

                // Bind Enlaces to repository
        $this->app->bind(
            'Wilsonwaldo\Sisep\Interfaces\EnlacesRepositoryInterface',
            \Wilsonwaldo\Sisep\Repositories\Eloquent\EnlacesRepository::class
        );

        $this->app->register(\Wilsonwaldo\Sisep\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Wilsonwaldo\Sisep\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['wilsonwaldo.sisep'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('wilsonwaldo/sisep.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/sisep')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/sisep')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
